# PytCube

**pytcube** is a python library for extracting small cubes around observation points within a large spatio-temporal grid.

## Installation

```bash
pip install pytcube
```

## Documentation

```bash
sphinx-build -M html docs docs/_build/
rm -rf docs/_build/
```